﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using Telerik.Windows.Cloud;
using Telerik.Everlive.Sdk.Core;
using Memories.Models;
using Telerik.Windows.Controls;
using System.Linq.Expressions;

namespace Memories.Views
{
    public partial class ViewMemory : PhoneApplicationPage
    {
        private Memory memory;

        public ViewMemory()
        {
            InitializeComponent();
        }

        protected async override void OnNavigatedTo(NavigationEventArgs e)
        {
            base.OnNavigatedTo(e);

            if (e.NavigationMode != NavigationMode.New)
            {
                return;
            }

            if (this.NavigationContext.QueryString.ContainsKey("id"))
            {
                string id = this.NavigationContext.QueryString["id"];
                Guid guid = new Guid(id);
                EverliveApp everliveApp = CloudProvider.Current.NativeConnection as EverliveApp;
                this.memory = await everliveApp.WorkWith().Data<Memory>().GetById(guid).ExecuteAsync();
                this.DataContext = this.memory;
                if (this.memory != null)
                {
                    InitCloudService();
                    return;
                }
            }

            await RadMessageBox.ShowAsync("Memory not found!");
        }

        private void OnEditButton_Click(object sender, EventArgs e)
        {
            this.NavigationService.Navigate(new Uri(string.Format("/Views/AddOrEditMemory.xaml?id={0}", this.memory.Id), UriKind.RelativeOrAbsolute));
        }

        private async void OnDeleteButton_Click(object sender, EventArgs e)
        {
            MessageBoxClosedEventArgs args = await RadMessageBox.ShowAsync("Delete memory?", "Deleting memory", MessageBoxButtons.OKCancel);
            if (args.Result == DialogResult.OK)
            {
                EverliveApp app = CloudProvider.Current.NativeConnection as EverliveApp;
                await app.WorkWith().Data<Memory>().Delete(this.memory.Id).TryExecuteAsync();
                PhoneApplicationService.Current.State["ReloadMemories"] = true;
                this.NavigationService.GoBack();
            }
        }

        private void OnAddImageButton_Click(object sender, EventArgs e)
        {
            gallery.AddNewPicture();
        }

        private async void InitCloudService()
        {
            EverliveCloudDataService<MemoryPicture> picturesService = new EverliveCloudDataService<MemoryPicture>();
            Expression<Func<MemoryPicture, bool>> filterExpression = picture => picture.MemoryId == this.memory.Id;
            picturesService.Filter = filterExpression;
            gallery.CloudDataService = picturesService;
            await gallery.ReloadCloudItemsAsync();
        }

        private void OnNewPictureItemCreating(object sender, Telerik.Windows.Controls.Cloud.NewPictureItemCreatingEventArgs e)
        {
            MemoryPicture newPicture = e.NewPictureItem as MemoryPicture;
            if (newPicture != null)
            {
                newPicture.MemoryId = this.memory.Id;
            }
        }
    }
}